This crate contains kube-rs compatible bindings for Kubernetes custom resources for the helm.sigstore.dev group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
helm.sigstore.dev/v1alpha1
Rekor